%bcond_with tests
%bcond_with optional_tests
%bcond_without timeout
%bcond_with docs

Summary:        Simple powerful testing with Python
Name:           pytest
Version:        7.1.3
Release:        3%{?dist}
License:        MIT
URL:            https://pytest.org
Source0:        https://github.com/pytest-dev/pytest/archive/refs/tags/7.1.3.tar.gz#/pytest-7.1.3.tar.gz
Patch3000:      pytest-7.1.3-fix-xfails.patch

BuildRequires:  python3-devel pyproject-rpm-macros >= 0-51

%if %{with tests}
BuildRequires:  python3-hypothesis >= 3.56 python3-pygments >= 2.7.2
BuildRequires:  python3-xmlschema

%if %{with optional_tests}
BuildRequires:  python3-argcomplete python3-decorator
BuildRequires:  python3-jinja2 python3-mock python3-nose
BuildRequires:  python3-numpy python3-pexpect
BuildRequires:  python3-pytest-xdist python3-twisted
BuildRequires:  /usr/bin/lsof
%endif
%if %{with timeout}
BuildRequires:  python3-pytest-timeout
%endif
%endif

%if %{with docs}
BuildRequires:  %{_bindir}/rst2html
BuildRequires:  python3-pluggy >= 1 python3-pygments-pytest
BuildRequires:  python3-Pallets-Sphinx-Themes python3-sphinx
BuildRequires:  python3-sphinx-removed-in python3-sphinxcontrib-trio
BuildRequires:  make
%endif

BuildArch:      noarch

%description
The pytest framework makes it easy to write small tests, yet scales to support
complex functional testing for applications and libraries.


%package -n python3-%{name}
Summary:        Simple powerful testing with Python
Provides:       pytest = %{version}-%{release}

%description -n python3-%{name}
The pytest framework makes it easy to write small tests, yet scales to support
complex functional testing for applications and libraries.


%prep
%autosetup -p1 -n %{name}-%{version}


%generate_buildrequires
%pyproject_buildrequires -r


%build
%pyproject_wheel

%if %{with docs}
for l in doc/* ; do
  %make_build -C $l html PYTHONPATH=%{pyproject_build_lib}
done
for f in README CHANGELOG CONTRIBUTING ; do
  rst2html ${f}.rst > ${f}.html
done
%endif


%install
%pyproject_install
%pyproject_save_files _pytest pytest

mv %{buildroot}%{_bindir}/pytest %{buildroot}%{_bindir}/pytest-%{python3_version}
ln -snf pytest-%{python3_version} %{buildroot}%{_bindir}/pytest-3
mv %{buildroot}%{_bindir}/py.test %{buildroot}%{_bindir}/py.test-%{python3_version}
ln -snf py.test-%{python3_version} %{buildroot}%{_bindir}/py.test-3


ln -snf pytest-%{python3_version} %{buildroot}%{_bindir}/pytest
ln -snf py.test-%{python3_version} %{buildroot}%{_bindir}/py.test

%if %{with docs}
mkdir -p _htmldocs/html
for l in doc/* ; do
  rm ${l}/_build/html/.buildinfo
  mv ${l}/_build/html _htmldocs/html/${l##doc/}
done
%endif

find %{buildroot}%{python3_sitelib} \
     -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' {} \;


%if %{with tests}
%check
%global __pytest %{buildroot}%{_bindir}/pytest
%pytest testing %{?with_timeout:--timeout=30} %{?with_optional_tests:-n auto} -rs
%endif


%files -n python3-%{name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%if %{with docs}
%doc CHANGELOG.html
%doc README.html
%doc CONTRIBUTING.html
%doc _htmldocs/html
%endif
%{_bindir}/pytest
%{_bindir}/pytest-3
%{_bindir}/pytest-%{python3_version}
%{_bindir}/py.test
%{_bindir}/py.test-3
%{_bindir}/py.test-%{python3_version}


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.1.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.1.3-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Mar 20 2023 Feng Weiyao <wynnfeng@tencent.com> - 7.1.3-1
- update to version 7.1.3

* Fri Dec 9 2022 Feng Weiyao <wynnfeng@tencent.com> - 6.2.5-1
- package init.